// src/transform.ts
import MagicString from "magic-string";
function transform(code, id, basic) {
  if (id.endsWith(".css")) {
    const s = new MagicString(code);
    const reg = /(?<=(\.|\#))(.*)(?=\s*\{)/g;
    const matches = Array.from(code.matchAll(reg));
    if (!matches.length)
      return;
    for (const match of matches) {
      const selector = match[0];
      const dot = match[1];
      const raw = `${dot}${selector}`;
      if (raw.includes(basic))
        continue;
      const start = match.index - 1;
      const end = start + selector.length + 1;
      const replacement = `${basic} ${raw}`;
      s.update(start, end, replacement);
    }
    return {
      code: s.toString(),
      map: s.generateMap()
    };
  }
}

// src/index.ts
function VitePluginBasicCssSelector(basic, options) {
  return {
    name: "vite-plugin-basic-css-selector",
    enforce: options == null ? void 0 : options.enforce,
    apply: options == null ? void 0 : options.apply,
    transform(code, id) {
      return transform(code, id, basic);
    }
  };
}
var src_default = VitePluginBasicCssSelector;
export {
  src_default as default
};
